@@ -14,6 +14,6 @@ class ErrorDataType:
         status = self.status or "-"
 
         return f"{self.message} - " \
-               f"{type(exception).__name__} - " \
+               f"{type(exception).__name__} " \
                f"[{status}]"
 
